@@ -118,8 +118,7 @@ do_message(char *msg)
     {
 	do_message(_("Operation failed"));
       dotogglehandler = 0;
-      [(Gtk_CheckButton *) obj
-			   set_state:!((Gtk_CheckButton *) obj)->gtktogglebutton->active];
+      [obj set_active:!((Gtk_CheckButton *) obj)->gtktogglebutton->active];
       dotogglehandler = 1;
     }
 
@@ -138,7 +137,7 @@ do_message(char *msg)
 
   if (curprinter == nil)
     {
-	do_message(_("You must select a printer"));
+      do_message(_("You must select a printer"));
       return self;
     }
 	
@@ -178,20 +177,27 @@ do_message(char *msg)
 
   [[self do_printer_list] do_job_list];
 
-  dotogglehandler = 0;
-  [self set_wait_cursor:TRUE];
-  [queueing set_state:[curprinter isUp]];
-  [printing set_state:[curprinter isStarted]];
-  [self set_wait_cursor:FALSE];
-  dotogglehandler = 1;
-
   return self;
 }
 
 - select_row:(id) obj :(gint) row :(gint) column :(GdkEventButton *) event
 {
-  if (obj == printer_list && doselecthandler)
+  if (obj == printer_list && doselecthandler) {
+    id curprinter = nil;
+
     [self do_job_list];
+
+    if (printer_list->gtkclist->selection)
+      curprinter = [printer_list get_row_data:GPOINTER_TO_INT(printer_list->gtkclist->selection->data)];
+    if(curprinter) {
+      dotogglehandler = 0;
+      [self set_wait_cursor:TRUE];
+      [queueing set_active:[curprinter isUp]];
+      [printing set_active:[curprinter isStarted]];
+      [self set_wait_cursor:FALSE];
+      dotogglehandler = 1;
+    }
+  }
   if (obj == job_list)
     [cancel_job set_sensitive:TRUE];
   return self;
@@ -232,9 +238,6 @@ do_message(char *msg)
     {
       job_list = [[[[Gtk_CList alloc] initWithTitles:4 :collist] show] freeze];
       [job_list set_selection_mode:GTK_SELECTION_BROWSE];
-      [job_list set_column_width:0 :40];
-      [job_list set_column_width:1 :200];
-      [job_list set_column_width:2 :40];
     }
 
   if (printer_list->gtkclist->selection)
@@ -245,18 +248,18 @@ do_message(char *msg)
   else
     newprt = nil;
 
-  dotogglehandler = FALSE;
-  [queueing set_state:[newprt isUp]];
-  [printing set_state:[newprt isStarted]];
-  dotogglehandler = TRUE;
-
-  vals[0] = idbuf;
-  vals[2] = sizebuf;
-
   [cancel_job set_sensitive:FALSE];
 
   if(newprt)
     {
+      dotogglehandler = FALSE;
+      [queueing set_active:[newprt isUp]];
+      [printing set_active:[newprt isStarted]];
+      dotogglehandler = TRUE;
+
+      vals[0] = idbuf;
+      vals[2] = sizebuf;
+
       if (newprt->numjobs > 0)
 	[cancel_job set_sensitive:TRUE];
 
@@ -273,6 +276,7 @@ do_message(char *msg)
     }
 
   [job_list thaw];
+  [job_list columns_autosize];
 
   [self set_wait_cursor:FALSE];
 
@@ -318,9 +322,6 @@ do_message(char *msg)
       printer_list = [[[[Gtk_CList alloc] initWithTitles:4 :(const char **)columns] show] freeze];
       [printer_list set_selection_mode:GTK_SELECTION_BROWSE];
       [printer_list connectObj:"select_row" :self];
-      [printer_list set_column_width:0 :60];
-      [printer_list set_column_width:1 :30];
-      [printer_list set_column_width:2 :60];
     }
 
   tmp = g_malloc(10);
@@ -349,19 +350,21 @@ do_message(char *msg)
     }
   g_free(tmp);
 
-  if (oldoffset >= 0)
-    {
-      [printer_list select_row:oldoffset :0];
-
-      printer = [printer_list get_row_data:GPOINTER_TO_INT(printer_list->gtkclist->selection->data)];
-
-      dotogglehandler = FALSE;
-      [queueing set_state:[printer isUp]];
-      [printing set_state:[printer isStarted]];
-      dotogglehandler = TRUE;
-    }
+  if (oldoffset < 0)
+    oldoffset = 0;
+  [printer_list select_row:oldoffset :0];
+  
+  printer = [printer_list get_row_data:GPOINTER_TO_INT(printer_list->gtkclist->selection->data)];
+  
+  dotogglehandler = 0;
+  [self set_wait_cursor:TRUE];
+  [queueing set_active:[printer isUp]];
+  [printing set_active:[printer isStarted]];
+  [self set_wait_cursor:FALSE];
+  dotogglehandler = 1;
 
   [printer_list thaw];
+  [printer_list columns_autosize];
   doselecthandler = TRUE;
 
   [self set_wait_cursor:FALSE];
@@ -380,26 +383,18 @@ do_message(char *msg)
   id  vbox;
 
   GnomeUIInfo filemenu[] = {
-    { GNOME_APP_UI_ITEM, N_("E_xit"), NULL, "menu_file_exit", NULL, NULL, 
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'x', GDK_CONTROL_MASK, NULL},
-    { GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
-	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
+    GNOMEUIINFO_MENU_EXIT_ITEM("menu_file_exit", NULL),
+    GNOMEUIINFO_END
   };
   GnomeUIInfo helpmenu[] = {
-    { GNOME_APP_UI_HELP, NULL, NULL, "gulp", NULL, NULL,
-	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-    { GNOME_APP_UI_ITEM, N_("_About..."), NULL, "menu_help_about", NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL},
-    { GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
-	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
+    GNOMEUIINFO_HELP("gulp"),
+    GNOMEUIINFO_MENU_ABOUT_ITEM("menu_help_about", NULL),
+    GNOMEUIINFO_END
   };
   GnomeUIInfo mainmenu[] = {
-    { GNOME_APP_UI_SUBTREE, N_("_Program"), NULL, &filemenu, NULL, NULL,
-	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-    { GNOME_APP_UI_SUBTREE, N_("_Help"), NULL, &helpmenu, NULL, NULL,
-	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-    { GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
-	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
+    GNOMEUIINFO_MENU_FILE_TREE(filemenu),
+    GNOMEUIINFO_MENU_HELP_TREE(helpmenu),
+    GNOMEUIINFO_END
   };
 	
   self = [super initApp:app_id :VERSION :argc :argv];
