@@ -1,6 +1,9 @@
 #include "logview.h"
 #include <string.h>
+#include <stdlib.h>
 #include <regex.h>
+#include <config.h>
+#include <gnome.h>
 
 #define MAX_NUM_MATCHES     10
 #define DELIM               ":"
@@ -45,24 +48,17 @@ GList *ctree_parent;
 void
 mon_edit_actions (GtkWidget *widget, gpointer data)
 {
-  GtkWidget *hbox, *hbox2;
-  GtkWidget *label;
-  GtkWidget *scrolled_win;
-  GtkWidget *list_item;
+  GtkWidget *hbox;
   GtkWidget *button;       
   GtkWidget *padding;       
-  GtkWidget *vbox2;
   GtkWidget *swin;
-  GtkStyle *style;
   GtkBox *vbox;
-  char buffer[10];
-  const gchar *title[] = {"Action database"};
-  int i;
+  const gchar *title[] = {N_("Action database")};
   
   /* Create main window ------------------------------------------------  */
   actions_dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_container_set_border_width (GTK_CONTAINER (actions_dialog), 5);
-  gtk_window_set_title (GTK_WINDOW (actions_dialog), "Monitor options");
+  gtk_window_set_title (GTK_WINDOW (actions_dialog), _("Monitor options"));
   gtk_widget_set_style (actions_dialog, cfg->main_style);
   gtk_widget_set_usize (actions_dialog, 400, -1);
   gtk_signal_connect (GTK_OBJECT (actions_dialog), "destroy",
@@ -79,11 +75,11 @@ mon_edit_actions (GtkWidget *widget, gpointer data)
   
   /* List with actions */
 
-  ctree = GTK_CTREE (gtk_ctree_new_with_titles (1, 0, title));
+  ctree = GTK_CTREE (gtk_ctree_new_with_titles (1, 0, (char **)title));
   swin = gtk_scrolled_window_new (NULL, NULL);
   gtk_container_add (GTK_CONTAINER (swin), GTK_WIDGET (ctree));
   gtk_ctree_set_line_style (ctree, GTK_CTREE_LINES_DOTTED);
-  gtk_ctree_set_reorderable (ctree, TRUE);
+  gtk_clist_set_reorderable (GTK_CLIST(ctree), TRUE);
   gtk_widget_set_usize (GTK_WIDGET (ctree), -1, 300);
 
 /* ----------------------------------------------------------------------
@@ -114,21 +110,21 @@ mon_edit_actions (GtkWidget *widget, gpointer data)
   gtk_box_pack_start (vbox, hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
-  button = gtk_button_new_with_label ("Add...");
+  button = gtk_button_new_with_label (_("Add..."));
   gtk_widget_set_usize (button, 80, 25);
   gtk_signal_connect (GTK_OBJECT (button), "clicked", 
 		      GTK_SIGNAL_FUNC (add_actions_entry_cb), NULL);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
   gtk_widget_show (button);
   
-  button = gtk_button_new_with_label ("Edit...");
+  button = gtk_button_new_with_label (_("Edit..."));
   gtk_widget_set_usize (button, 80, 25);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (button), "clicked", 
 		      GTK_SIGNAL_FUNC (edit_actions_entry_cb), NULL);
   gtk_widget_show (button);
   
-  button = gtk_button_new_with_label ("Remove");
+  button = gtk_button_new_with_label (_("Remove"));
   gtk_widget_set_usize (button, 80, 25);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
   gtk_widget_show (button);
@@ -142,12 +138,12 @@ mon_edit_actions (GtkWidget *widget, gpointer data)
   gtk_widget_show (padding);
   gtk_box_pack_start (GTK_BOX (hbox), padding, TRUE, TRUE, 0);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   gtk_widget_set_usize (button, 80, 25);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label ("OK");
+  button = gtk_button_new_with_label (_("OK"));
   gtk_widget_set_usize (button, 80, 25);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
   gtk_widget_show (button);
@@ -187,18 +183,19 @@ make_tree_from_actions_db (GList *db)
     {
       action = (Action *)item->data;
       if (strncmp (buffer, action->tag, 49) == 0)
-	sibling = gtk_ctree_insert_node (ctree, sibling, NULL, text, 5, NULL, NULL,
+	sibling = (GList *)gtk_ctree_insert_node (ctree, (GtkCTreeNode *)sibling, NULL, (char **)text, 5, NULL, NULL,
 				    NULL, NULL, FALSE, FALSE);
       else
 	{
 	  strncpy (buffer, action->tag, 50);
-	  sibling = gtk_ctree_insert_node (ctree, ctree_parent, NULL, text, 5, NULL, NULL,
+	  sibling = (GList *)gtk_ctree_insert_node (ctree, (GtkCTreeNode *)ctree_parent, NULL, (char **)text, 5, NULL, NULL,
 				      NULL, NULL, FALSE, FALSE);
 	  if (ctree_parent == NULL)
 	    ctree_parent = sibling;
 	}
       /* Store data in tree */
-      gtk_ctree_node_set_row_data (ctree, sibling, (gpointer) action);
+      gtk_ctree_node_set_row_data (ctree, (GtkCTreeNode *)sibling,
+				   (gpointer) action);
     }
 
   /* done. */
@@ -281,7 +278,7 @@ read_actions_db (char *filename, GList **db)
       tok = strtok (c1, DELIM);
       if (tok == NULL)
 	{
-	  ShowErrMessage ("Error parsing actions data base");
+	  ShowErrMessage (_("Error parsing actions data base"));
 	  free_actions_db (db);
 	  return (-1);
 	}
@@ -294,7 +291,7 @@ read_actions_db (char *filename, GList **db)
 	item->log_name = g_strdup (tok);
       else
 	{
-	  ShowErrMessage ("Error parsing actions data base");
+	  ShowErrMessage (_("Error parsing actions data base"));
 	  free_actions_db (db);
 	  return (-1);
 	}
@@ -305,7 +302,7 @@ read_actions_db (char *filename, GList **db)
 	item->process = g_strdup (tok);
       else
 	{
-	  ShowErrMessage ("Error parsing actions data base");
+	  ShowErrMessage (_("Error parsing actions data base"));
 	  free_actions_db (db);
 	  return (-1);
 	}
@@ -316,7 +313,7 @@ read_actions_db (char *filename, GList **db)
 	item->message = g_strdup (tok);
       else
 	{
-	  ShowErrMessage ("Error parsing actions data base");
+	  ShowErrMessage (_("Error parsing actions data base"));
 	  free_actions_db (db);
 	  return (-1);
 	}
@@ -327,7 +324,7 @@ read_actions_db (char *filename, GList **db)
 	item->description = g_strdup (tok);
       else
 	{
-	  ShowErrMessage ("Error parsing actions data base");
+	  ShowErrMessage (_("Error parsing actions data base"));
 	  free_actions_db (db);
 	  return (-1);
 	}
@@ -338,7 +335,7 @@ read_actions_db (char *filename, GList **db)
 	item->action = g_strdup (tok);
       else
 	{
-	  ShowErrMessage ("Error parsing actions data base");
+	  ShowErrMessage (_("Error parsing actions data base"));
 	  free_actions_db (db);
 	  return (-1);
 	}
@@ -370,7 +367,7 @@ write_actions_db (char *filename, GList *db)
   fp = fopen (filename, "w");
   if (fp == NULL)
     {
-      ShowErrMessage ("Can't write to actions database!");
+      ShowErrMessage (_("Can't write to actions database!"));
       return -1;
     }
   
@@ -384,7 +381,7 @@ write_actions_db (char *filename, GList *db)
     {
       action = (Action *)item->data;
       /* Check that there is a valid entry */
-      if (*action->tag = '\0' || action->log_name == NULL ||
+      if (*action->tag == '\0' || action->log_name == NULL ||
 	   action->process == NULL || action->message == NULL ||
 	   action->description == NULL ||
 	   action->action == NULL)
@@ -476,12 +473,12 @@ add_actions_entry_cb (GtkWidget *widget, gpointer data)
 
   action = malloc (sizeof (Action));
   
-  sprintf (action->tag, "<empty>");
-  action->log_name = g_strdup ("log. name regexp");
-  action->process = g_strdup ("process regexp");
-  action->message = g_strdup ("message regexp");
-  action->action = g_strdup ("action to execute when regexps are TRUE");
-  action->description = g_strdup ("description");
+  sprintf (action->tag, _("<empty>"));
+  action->log_name = g_strdup (_("log. name regexp"));
+  action->process = g_strdup (_("process regexp"));
+  action->message = g_strdup (_("message regexp"));
+  action->action = g_strdup (_("action to execute when regexps are TRUE"));
+  action->description = g_strdup (_("description"));
 
   edit_action_entry (action);
 
@@ -495,7 +492,6 @@ add_actions_entry_cb (GtkWidget *widget, gpointer data)
 void
 edit_actions_entry_cb (GtkWidget *widget, gpointer data)
 {
-  int row, column;
   GList *item;
   Action *action;
 
@@ -503,7 +499,7 @@ edit_actions_entry_cb (GtkWidget *widget, gpointer data)
   if (item == NULL)
     return;
 
-  action = (Action *) gtk_ctree_node_get_row_data(ctree, item);
+  action = (Action *) gtk_ctree_node_get_row_data(ctree, (GtkCTreeNode *)item);
 
   edit_action_entry (action);
 
@@ -517,20 +513,15 @@ edit_actions_entry_cb (GtkWidget *widget, gpointer data)
 void
 edit_action_entry (Action *action)
 {
-  GtkWidget *hbox, *hbox2;
+  GtkWidget *hbox;
   GtkWidget *label;
   GtkWidget *text;
   GtkWidget *entry;
   GtkWidget *action_record;
-  GtkWidget *scrolled_win;
-  GtkWidget *list_item;
   GtkWidget *button;       
   GtkWidget *padding;       
-  GtkWidget *vbox2;       
-  GtkStyle *style;
   GtkBox *vbox;
   GtkTooltips *tips;
-  int i;
 
   if (!action)
     return;
@@ -644,7 +635,7 @@ edit_action_entry (Action *action)
   hbox = gtk_hbox_new (FALSE, 2);
   gtk_box_pack_start (vbox, hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
-  label = gtk_label_new ("description:");
+  label = gtk_label_new (_("description:"));
   gtk_widget_set_usize (label, 60, -1);
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
   gtk_widget_show (label);
@@ -653,7 +644,7 @@ edit_action_entry (Action *action)
   gtk_text_set_editable (GTK_TEXT (text), TRUE);
   gtk_box_pack_start (GTK_BOX (hbox), text, TRUE, TRUE, 0);
   gtk_entry_set_text (GTK_ENTRY (entry), action->action);
-  gtk_tooltips_set_tip (tips, text, "Description of this entry.",
+  gtk_tooltips_set_tip (tips, text, _("Description of this entry."),
 			NULL);
   gtk_widget_show (text); 
 
@@ -668,12 +659,12 @@ edit_action_entry (Action *action)
   gtk_widget_show (padding);
   gtk_box_pack_start (GTK_BOX (hbox), padding, TRUE, TRUE, 0);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   gtk_widget_set_usize (button, 80, 25);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label ("OK");
+  button = gtk_button_new_with_label (_("OK"));
   gtk_widget_set_usize (button, 80, 25);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, TRUE, 0);
   gtk_widget_show (button);
@@ -709,15 +700,14 @@ print_actions_db (GList *db)
 {
   GList *item;
   Action *action;
-  int not_found;
 
   /* Search for daemon in our list */
   
   for (item = g_list_first (db); item != NULL; item = item->next)
     {
       action = (Action *)item->data;
-      printf ("tag: [%s]\n log_name: [%s]\n process: [%s] message: [%s]\n \
-		description: [%s]\n action: [%s]\n ", 
+      printf (_("tag: [%s]\nlog_name: [%s]\nprocess: [%s]\nmessage: [%s]\n"
+		"description: [%s]\naction: [%s]\n"), 
 	      action->tag,
 	      action->log_name,
 	      action->process,
@@ -741,7 +731,6 @@ clear_actions_db (GList *db)
 {
   GList *item;
   Action *action;
-  int not_found;
 
   for (item = g_list_first (db); item != NULL; item = item->next)
     {
