@@ -79,6 +79,7 @@ Log *curlog;
 int numlogs, curlognum;
 int log_line_sep;
 int cursor_visible;
+int canvas_width, canvas_height;
 char *deflognames[] =
 {PATH_MESSAGES};
 
@@ -111,7 +112,6 @@ void EraseLogCursor (int y);
 void Draw3DBox (GdkDrawable *win, GdkGC *gc, int x, int y, int w, int h, GdkColor color[3]);
 void CloseApp ();
 void UpdateStatusArea ();
-void InitCalendarData ();
 void change_log (int direction);
 void create_zoom_view (GtkWidget * widget, gpointer user_data);
 void close_zoom_view (GtkWidget * widget, GtkWindow ** window);
@@ -306,10 +306,7 @@ change_log (int direction)
   if (loginfovisible)
     RepaintLogInfo (NULL, NULL);
   if (calendarvisible)
-    {
-      InitCalendarData ();
-      RepaintCalendar (NULL, NULL);
-    }
+    init_calendar_data ();
   UpdateStatusArea();
 }
 
@@ -326,6 +323,7 @@ ScrollDown (int howmuch)
 
   ln = curlog->firstline;
   ln += howmuch;
+
   while (ln >= LINES_P_PAGE && !curlog->currentpg->islastpage )
     {
       ln -= LINES_P_PAGE;
@@ -334,6 +332,10 @@ ScrollDown (int howmuch)
 	ReadNPagesDown (curlog, next, (NUM_PAGES>>1));
       curlog->currentpg = curlog->currentpg->next;
     }
+
+  if (ln > curlog->currentpg->ll && curlog->currentpg->islastpage)
+    ln = curlog->currentpg->ll;
+
   curlog->firstline = ln;
 }
 
@@ -411,7 +413,7 @@ log_repaint (GtkWidget * win, GdkEventExpose * event)
      gdk_window_clear_area (canvas, area->x, area->y, 
 			    area->width, area->height);
    else
-     gdk_window_clear (canvas);
+     gdk_window_clear (canvas); /* <-- This causes a LOT of flickering! */
 
    /* Check that there is at least one log */
    if (curlog == NULL)
@@ -424,7 +426,8 @@ log_repaint (GtkWidget * win, GdkEventExpose * event)
 
    log_redrawdetail ();
 
-   while ((y - offset) < LOG_CANVAS_H)
+   gdk_window_get_size (canvas, &canvas_width, &canvas_height);
+   while ((y - offset) < canvas_height)
    {
       line = &pg->line[ln];
       if ((line->month != cm && line->month > 0) ||
@@ -443,7 +446,7 @@ log_repaint (GtkWidget * win, GdkEventExpose * event)
       ln++;
       if (ln > pg->ll && pg->islastpage == TRUE)
 	 break;
-      if (ln > LINES_P_PAGE-1)
+      if (ln > pg->ll)
       {
 	 if (pg->islastpage == FALSE)
 	    pg = pg->next;
@@ -505,7 +508,8 @@ log_redrawcursor (int ol, int nl, Page * np)
    cm = cd = -1;
    y = offset;
 
-   while ((y - offset) < LOG_CANVAS_H)
+   gdk_window_get_size (canvas, &canvas_width, &canvas_height);
+   while ((y - offset) < canvas_height)
    {
       line = &pg->line[ln];
       if ((line->month != cm && line->month >= 0) ||
@@ -548,24 +552,30 @@ log_redrawcursor (int ol, int nl, Page * np)
 void
 DrawLogLine (LogLine *line, int y)
 {
-   char tmp[90];
+  char tmp[1024];
+  int num_chars, max_num_chars;
+  
+  /*gdk_gc_set_foreground (gc, &cfg->white); */
+  gdk_gc_set_foreground (gc, &cfg->black);
+  
+  if (line->hour >= 0 && line->min >= 0 && line->sec >= 0)
+    sprintf (tmp, "%02d:%02d:%02d", line->hour, line->min, line->sec);
+  else
+    sprintf (tmp, " ");
+  gdk_draw_string (canvas, cfg->fixedb, gc, LOG_COL1, y, tmp);
+  sprintf (tmp, "%s", line->process);
+  if (strlen (tmp) > 13)
+    tmp[13] = '\0';
+  gdk_draw_string (canvas, cfg->fixed, gc, LOG_COL2, y, tmp);
 
-   /*gdk_gc_set_foreground (gc, &cfg->white); */
-   gdk_gc_set_foreground (gc, &cfg->black);
-
-   if (line->hour >= 0 && line->min >= 0 && line->sec >= 0)
-      sprintf (tmp, "%02d:%02d:%02d", line->hour, line->min, line->sec);
-   else
-      sprintf (tmp, " ");
-   gdk_draw_string (canvas, cfg->fixedb, gc, LOG_COL1, y, tmp);
-   sprintf (tmp, "%s", line->process);
-   if (strlen (tmp) > 13)
-      tmp[13] = '\0';
-   gdk_draw_string (canvas, cfg->fixed, gc, LOG_COL2, y, tmp);
-   strncpy (tmp, line->message, 90);
-   if (strlen (tmp) > 67)
-      tmp[67] = '\0';
-   gdk_draw_string (canvas, cfg->fixed, gc, LOG_COL3, y, tmp);
+  num_chars = MAX (strlen (line->message), 1023);
+  tmp[1023] = '\0';
+  strncpy (tmp, line->message, 1023);
+  max_num_chars = (canvas_width - 10 - LOG_COL3) / gdk_char_width (cfg->fixed, 'A');
+  if (max_num_chars < num_chars)
+    max_num_chars = num_chars;
+  tmp[max_num_chars] = '\0';
+  gdk_draw_string (canvas, cfg->fixed, gc, LOG_COL3, y, tmp);
 }
 
 
@@ -585,7 +595,7 @@ DrawMonthHeader (LogLine * line, int y)
    h = cfg->headingb->ascent - cfg->headingb->descent;
    skip = (log_line_sep - cfg->fixed->ascent + cfg->fixed->descent);
    centery = y + log_line_sep - ((2 * log_line_sep - skip - h) >> 1);
-   Draw3DBox (canvas, gc, 5, y - log_line_sep + skip , LOG_CANVAS_W - 10, 2*log_line_sep-skip, color);
+   Draw3DBox (canvas, gc, 5, y - log_line_sep + skip , canvas_width - 10, 2*log_line_sep-skip, color);
 
    gdk_gc_set_foreground (gc, &cfg->black);
    sprintf (buf, "%s %d", _(month[(int) line->month]), line->date);
@@ -606,7 +616,7 @@ DrawLogCursor (int y)
    GdkColor color[] =
    {cfg->gray25, cfg->gray50, cfg->gray75};
 
-   Draw3DBox (canvas, gc, 5, y - log_line_sep + 3, LOG_CANVAS_W - 10, log_line_sep, color);
+   Draw3DBox (canvas, gc, 5, y - log_line_sep + 3, canvas_width - 10, log_line_sep, color);
 }
 
 /* ----------------------------------------------------------------------
@@ -641,7 +651,7 @@ Draw3DBox (GdkDrawable *win, GdkGC *gc, int x, int y, int w, int h, GdkColor col
 void
 EraseLogCursor (int y)
 {
-  gdk_window_clear_area (canvas, 5, y - log_line_sep + 3, LOG_CANVAS_W - 10, log_line_sep);
+  gdk_window_clear_area (canvas, 5, y - log_line_sep + 3, canvas_width - 10, log_line_sep);
 }
 
 
@@ -705,7 +715,7 @@ GetLineAtCursor (int y)
    int maxnumlines;
 
    sln = (y + 13 - LOG_TITLEY) / log_line_sep - 2;
-   maxnumlines = LOG_CANVAS_H / log_line_sep;
+   maxnumlines = canvas_height / log_line_sep;
 
    /* Check that we are at least bellow the header, */
    if (sln < 0)
@@ -764,7 +774,7 @@ GetPageAtCursor (int y)
    int maxnumlines;
 
    sln = (y + 13 - LOG_TITLEY) / log_line_sep - 2;
-   maxnumlines = LOG_CANVAS_H / log_line_sep;
+   maxnumlines = canvas_height / log_line_sep;
 
    ln = curlog->firstline;
    pg = curlog->currentpg;
