@@ -96,6 +96,7 @@ OpenLogFile (char *filename)
       ShowErrMessage (_("Not enough memory!\n"));
       return ((Log *) NULL);
    }
+   memset (tlog, 0, sizeof (Log));
    /* Alloc memory for pages ------------------------------ */
    tlog->currentpg = (Page *) malloc (sizeof (Page));
    if (tlog->currentpg == NULL)
@@ -390,9 +391,7 @@ ReadPageDown (Log * lg, Page * pg)
 	 if (ln == 0)
 	    pg->prev->islastpage = TRUE;
 	 else
-	   {
-	    pg->islastpage = TRUE;
-	   }
+	   pg->islastpage = TRUE;
 	 ungetc (ch, fp);
 	 break;
       }
@@ -420,10 +419,7 @@ ReadPageDown (Log * lg, Page * pg)
       ParseLine (buffer, line);
       ln++;
    }
-   if (pg->ll != LINES_P_PAGE)
-     pg->ll = ln-1;
-   else
-     pg->ll = LINES_P_PAGE-1;
+   pg->ll = ln-1;
    pg->lastchpos = ftell (fp);
 
    return TRUE;
@@ -815,10 +811,10 @@ MoveToMark (Log *log)
   Page *middlepg;
   int pagesread, pagesdown, i;
   
-  if (log == NULL)
-    return;
+  g_return_if_fail (log);
   
   mark = log->curmark;
+  g_return_if_fail (mark);
   fp = log->fp;
   
   pagesdown = NUM_PAGES>>1;
