@@ -29,6 +29,7 @@
 #include "gtk/gtk.h"
 #include "logview.h"
 #include "gnome.h"
+#include "log.xpm"
 
 /*
  *    -------------------
@@ -50,11 +51,11 @@ void CalendarMenu (GtkWidget * widget, gpointer user_data);
 void MonitorMenu (GtkWidget* widget, gpointer user_data); 
 void create_zoom_view (GtkWidget * widget, gpointer user_data);
 void AboutShowWindow (GtkWidget* widget, gpointer user_data);
-void AboutHideWindow ();
 void CloseApp ();
 void CloseLog (Log *);
 void ShowErrMessage (char *);
 void MainWinScrolled (GtkAdjustment *adjustment, GtkRange *);
+void CanvasResized (GtkWidget *widget, GtkAllocation *allocation);
 void ScrollWin (GtkRange *range, gpointer event);
 void LogInfo (GtkWidget * widget, gpointer user_data);
 void UpdateStatusArea ();
@@ -132,14 +133,11 @@ GnomeUIInfo help_menu[] = {
 };
 
 GnomeUIInfo main_menu[] = {
-        {GNOME_APP_UI_SUBTREE, N_("File"), NULL, file_menu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_SUBTREE, N_("View"), NULL, view_menu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_SUBTREE, N_("Filter"), NULL,  filter_menu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_SUBTREE, N_("Help"), NULL,  help_menu, NULL, NULL,
+	GNOMEUIINFO_MENU_FILE_TREE(file_menu),
+	GNOMEUIINFO_MENU_VIEW_TREE(view_menu),
+        {GNOME_APP_UI_SUBTREE, N_("F_ilter"), NULL,  filter_menu, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+	GNOMEUIINFO_MENU_HELP_TREE(help_menu),
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
                  
@@ -228,9 +226,6 @@ InitApp ()
   if (InitPages () < 0)
     ShowErrMessage (_("No log files to open"));
 
-  /*  Remove about window */
-  /* AboutHideWindow (); */
-
   /*  Display main window */
   CreateMainWin ();
 
@@ -248,16 +243,24 @@ void
 CreateMainWin ()
 {
    GtkWidget *canvas;
-   GtkWidget *box, *hbox, *hbox2;
+   GtkWidget *w, *box, *hbox, *hbox2;
    GtkWidget *frame, *padding;
    GtkLabel *label;
    GtkObject *adj;
+   GdkPixmap *icon_pixmap;
+   GdkBitmap *icon_bitmap;
+   GtkAllocation req_size;
 
    /* Create App */
 
    app = gnome_app_new ("Logview", _("System Log Viewer"));
 
-   gtk_container_set_border_width ( GTK_CONTAINER (app), 3);
+   gtk_container_set_border_width ( GTK_CONTAINER (app), 0);
+   gtk_window_set_default_size ( GTK_WINDOW (app), LOG_CANVAS_W, LOG_CANVAS_H);
+   req_size.x = req_size.y = 0;
+   req_size.width = 400;
+   req_size.height = 400;
+   gtk_widget_size_allocate ( GTK_WIDGET (app), &req_size );
    gtk_signal_connect (GTK_OBJECT (app), "destroy",
 		       GTK_SIGNAL_FUNC (destroy), NULL);
    gtk_signal_connect (GTK_OBJECT (app), "delete_event",
@@ -288,18 +291,29 @@ CreateMainWin ()
 
    hbox = gtk_hbox_new (FALSE, 0);
 
+   w = gtk_scrolled_window_new (NULL, NULL);
+   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (w),
+				   GTK_POLICY_AUTOMATIC, 
+				   GTK_POLICY_AUTOMATIC);
+   gtk_widget_show (w);
+               
    canvas = gtk_drawing_area_new ();
-   gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), LOG_CANVAS_W, LOG_CANVAS_H);
-   gtk_box_pack_start (GTK_BOX(hbox), canvas, TRUE, TRUE, 0);
+   //gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W, LOG_CANVAS_H); 
+   gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W, 10); 
+   //gtk_widget_set_usize ( GTK_WIDGET (canvas), LOG_CANVAS_W, LOG_CANVAS_H);
+   gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (w), canvas);
+   gtk_box_pack_start (GTK_BOX(hbox), w, TRUE, TRUE, 0);
 
    if (curlog != NULL)
      adj = gtk_adjustment_new ( curlog->ln, 0.0, curlog->lstats.numlines+LINES_P_PAGE, 
-				1.0, 10.0, (float) LINES_P_PAGE);
+				1.0, 10.0, (float) 1);
    else
      adj = gtk_adjustment_new (100.0, 0.0, 101.0, 1, 10, LINES_P_PAGE);
+
    main_win_scrollbar = (GtkWidget *)gtk_vscrollbar_new (GTK_ADJUSTMENT(adj));
    gtk_range_set_update_policy (GTK_RANGE (main_win_scrollbar), GTK_UPDATE_CONTINUOUS);
-   gtk_box_pack_start (GTK_BOX(hbox), main_win_scrollbar, TRUE, TRUE, 0);
+
+   gtk_box_pack_start (GTK_BOX(hbox), main_win_scrollbar, FALSE, FALSE, 0);
    gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
 		       (GtkSignalFunc) MainWinScrolled,
 		       (gpointer) main_win_scrollbar);       
@@ -307,8 +321,11 @@ CreateMainWin ()
  		       (GtkSignalFunc) ScrollWin, 
  		       (gpointer) main_win_scrollbar);        
    gtk_widget_show (main_win_scrollbar);  
-   
+
+
    gtk_container_add (GTK_CONTAINER (frame), hbox);
+
+
    
    /*  Install event handlers */
    gtk_signal_connect (GTK_OBJECT (canvas), "expose_event",
@@ -319,6 +336,8 @@ CreateMainWin ()
 		       GTK_SIGNAL_FUNC (HandleLogKeyboard), NULL);
    gtk_signal_connect (GTK_OBJECT (app), "button_press_event",
 		       GTK_SIGNAL_FUNC (handle_log_mouse_button), NULL);
+   gtk_signal_connect (GTK_OBJECT (canvas), "size_allocate",
+		       GTK_SIGNAL_FUNC (CanvasResized), NULL);
    gtk_widget_set_events (canvas, GDK_EXPOSURE_MASK |
 			  GDK_BUTTON_PRESS_MASK |
 			  GDK_POINTER_MOTION_MASK );
@@ -365,10 +384,39 @@ CreateMainWin ()
    gtk_widget_show (hbox2);
 
    gtk_box_pack_start (GTK_BOX (box), hbox2, FALSE, FALSE, 0);
+
    gtk_widget_show (box);
    gtk_widget_show (hbox);
    gtk_widget_show (app);
 
+   // Create application icon using tigerts' log
+   icon_pixmap = gdk_pixmap_create_from_xpm_d (frame->window, &icon_bitmap, 
+					       NULL, log_xpm);
+   if (icon_pixmap)
+     {
+       gdk_window_set_icon (GTK_WIDGET(app)->window, NULL, icon_pixmap, icon_bitmap);
+       gdk_window_set_icon_name (GTK_WIDGET(app)->window, "Logview");
+     }
+   else
+     fprintf (stderr, "Couldn't create icon pixmap!\n");
+   
+
+}
+
+/* ----------------------------------------------------------------------
+   NAME:          MainScreenResized
+   DESCRIPTION:   The main screen was resized.
+   ---------------------------------------------------------------------- */
+
+void
+CanvasResized (GtkWidget *widget, GtkAllocation *allocation)
+{
+  if (allocation)
+    printf ("Main screen resized!\n New size = (%d,%d)\n", 
+	    allocation->width, allocation->height);
+  else
+    printf ("Main screen resized!\nNo allocation :(\n");
+
 }
 
 /* ----------------------------------------------------------------------
@@ -410,8 +458,11 @@ MainWinScrolled (GtkAdjustment *adjustment, GtkRange *range)
 
   newln = (int) range->adjustment->value;
 
-  if (newln >= curlog->lstats.numlines || newln == 0)
-    return;
+ if (newln == 0)
+   return;
+
+ if (newln >= curlog->lstats.numlines)
+   newln == curlog->lstats.numlines - 1;
 
   /* Find mark which has this line */
   mark = curlog->curmark;
@@ -452,16 +503,15 @@ MainWinScrolled (GtkAdjustment *adjustment, GtkRange *range)
   /* Update status area */
   UpdateStatusArea ();
 
+  /* Only scroll when the scrollbar is released */
   if (howmuch > 0)
       ScrollDown (howmuch);
   else
       ScrollUp (-1*howmuch);
 
-  /* Repaint screen */
   if (howmuch != 0)
     log_repaint(NULL, NULL);
   
-
   return;
 }
 
@@ -476,7 +526,8 @@ void set_scrollbar_size (int num_lines)
   GtkObject *adj;
 
 
-  adj = gtk_adjustment_new ( curlog->ln, 0.0, num_lines+LINES_P_PAGE, 1.0, 10.0, (float) LINES_P_PAGE);
+  /*adj = gtk_adjustment_new ( curlog->ln, 0.0, num_lines+LINES_P_PAGE, 1.0, 10.0, (float) LINES_P_PAGE);*/
+  adj = gtk_adjustment_new ( curlog->ln, 0.0, num_lines+LINES_P_PAGE, 1.0, 10.0, (float) 1);
   gtk_range_set_adjustment ( GTK_RANGE (main_win_scrollbar), GTK_ADJUSTMENT (adj) );
   gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
 		      (GtkSignalFunc) MainWinScrolled,
@@ -570,9 +621,10 @@ FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
        return;
      }
 
-   strncpy(f, gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs)), 254);;
+   strncpy(f, gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs)), 254);
    f[254] = '\0';
    gtk_widget_destroy (GTK_WIDGET (fs));
+
    open_log_visible = FALSE;
    if (f != NULL)
       if ((tl = OpenLogFile (f)) != NULL)
@@ -587,12 +639,9 @@ FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
 	 /* Clear window */
 	 log_repaint (NULL, NULL);
 	 if (loginfovisible)
-	    RepaintLogInfo (NULL, NULL);
+	   RepaintLogInfo (NULL, NULL);
 	 if (calendarvisible)
-	   {
-	     InitCalendarData();
-	     RepaintCalendar (NULL, NULL);
-	   }
+	   init_calendar_data();
 	 UpdateStatusArea();
 	 set_scrollbar_size (curlog->lstats.numlines);
 	 if (numlogs >= 2)
@@ -622,7 +671,12 @@ LoadLogMenu (GtkWidget * widget, gpointer user_data)
 
 
    filesel = gtk_file_selection_new (_("Open new logfile"));
-   gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel), PATH_MESSAGES);
+
+   /* Make window modal */
+   gtk_window_set_modal (GTK_WINDOW (filesel), TRUE);
+
+   gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel), 
+   				    PATH_MESSAGES);
    gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
    gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
 		       "clicked", (GtkSignalFunc) FileSelectOk,
@@ -753,3 +807,16 @@ open_databases ()
 
   return;
 }
+
+/* ----------------------------------------------------------------------
+   NAME:          IsLeapYear
+   DESCRIPTION:   Return TRUE if year is a leap year.
+   ---------------------------------------------------------------------- */
+int
+IsLeapYear (int year)
+{
+   if ((1900 + year) % 4 == 0)
+      return TRUE;
+   else
+      return FALSE;
+}
