@@ -20,6 +20,8 @@
 
 
 #include <time.h>
+#include <config.h>
+#include <gnome.h>
 #include "gtk/gtk.h"
 #include "logview.h"
 #include "logrtns.h"
@@ -109,7 +111,7 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
        /* monoptions = gtk_dialog_new ();   */
       monoptions = gtk_window_new (GTK_WINDOW_TOPLEVEL);
       gtk_container_set_border_width (GTK_CONTAINER (monoptions), 5);
-      gtk_window_set_title (GTK_WINDOW (monoptions), "Monitor options");
+      gtk_window_set_title (GTK_WINDOW (monoptions), _("Monitor options"));
       gtk_widget_set_style (monoptions, cfg->main_style);
       gtk_signal_connect (GTK_OBJECT (monoptions), "destroy",
 			  GTK_SIGNAL_FUNC (close_monitor_options),
@@ -126,7 +128,7 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
       style = gtk_style_new ();
       memcpy (style, cfg->main_style, sizeof(GtkStyle));
       style->font = cfg->heading;
-      label = gtk_label_new ("Choose logs to monitor");
+      label = gtk_label_new (_("Choose logs to monitor"));
       gtk_misc_set_alignment(GTK_MISC (label), 0.0, 0.0);
       gtk_widget_set_style (label, style);
       gtk_box_pack_start (vbox, label, TRUE, TRUE, 0);
@@ -205,16 +207,16 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
       gtk_widget_show (hbox2);
 
       /* Check boxes */
-      button = gtk_check_button_new_with_label ("Hide app");
-      gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), FALSE);
+      button = gtk_check_button_new_with_label (_("Hide app"));
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
       gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, TRUE, 0);
       gtk_signal_connect (GTK_OBJECT (button), "clicked",
                           GTK_SIGNAL_FUNC (mon_hide_app_checkbox),
                           srclist);
       gtk_widget_show (button);
       
-      button = gtk_check_button_new_with_label ("Exec actions");
-      gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+      button = gtk_check_button_new_with_label (_("Exec actions"));
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
       gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, TRUE, 0);
       gtk_signal_connect (GTK_OBJECT (button), "clicked",
                           GTK_SIGNAL_FUNC (mon_actions_checkbox),
@@ -277,7 +279,7 @@ mon_add_log (GtkWidget *widget,
   tmp_list = GTK_LIST (srclist)->selection;
   if (tmp_list == NULL)
     {
-    printf ("tmp_list is NULL\n");
+    printf (_("tmp_list is NULL\n"));
     return;
     }
   name = gtk_widget_get_name (tmp_list->data);
@@ -324,7 +326,7 @@ mon_remove_log (GtkWidget *widget,
   tmp_list = GTK_LIST (destlist)->selection;
   if (tmp_list == NULL)
     {
-      printf ("tmp_list is NULL\n");
+      printf (_("tmp_list is NULL\n"));
       return;
     }
   name = gtk_widget_get_name (tmp_list->data);
@@ -400,7 +402,6 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
    GtkWidget *notebook;
    GtkWidget *frame;
    GtkWidget *vbox;
-   GtkWidget *tmpwidget;
    GtkCList *clist;
    GList *tmplist;
    char logfile[256];
@@ -452,7 +453,7 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
    /* monwindow = gtk_window_new (GTK_WINDOW_POPUP);  */ /*  Window without borders! */
    monwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_set_border_width (GTK_CONTAINER (monwindow), 0);
-   gtk_window_set_title (GTK_WINDOW (monwindow), "Monitoring logs..");
+   gtk_window_set_title (GTK_WINDOW (monwindow), _("Monitoring logs.."));
    gtk_widget_set_style (monwindow, cfg->main_style);
 
    gtk_widget_set_usize(monwindow, w, h);
@@ -539,7 +540,7 @@ mon_read_last_page (Log *log)
       if (i<0)
 	continue;
       mon_format_line (buffer, &pg.line[i]);
-      gtk_clist_append (log->mon_lines, texts);
+      gtk_clist_append (log->mon_lines, (char **)texts);
       log->mon_numlines++;
       if (log->mon_numlines > MON_MAX_NUM_LINES)
 	{
@@ -579,7 +580,7 @@ mon_read_new_lines (Log *log)
       for (i=pg.fl;i<pg.ll;i++)
 	{
 	  mon_format_line (buffer, &pg.line[i]);
-	  gtk_clist_append (log->mon_lines, texts);
+	  gtk_clist_append (log->mon_lines, (char **)texts);
 	  log->mon_numlines++;
 	} 
       if (log->mon_numlines > MON_MAX_NUM_LINES)
@@ -630,7 +631,7 @@ mon_check_logs (gpointer data)
       continue;
     mon_read_new_lines (loglist[i]);
 
-fprintf(stderr, "TOUCHED!!\n");
+fprintf(stderr, _("TOUCHED!!\n"));
 
     }
     return TRUE;
